@@ -6,7 +6,7 @@ from soil.filesystem import temporary_directory
 from beanstalk import IDENTIFIER
 from beanstalk.decorators import beanstalk_role
 from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings
-from beanstalk.titles import tool_title
+from beanstalk.titles import tool_title, section_title
 
 
 @task
@@ -23,13 +23,14 @@ def setup(settings_path=None, **settings_patches):
     beanstalk_stack_base = beanstalk_settings['BEANSTALK_STACK_BASE']
 
     # Install packages for building uwsgi
+    print section_title('Install system packages')
     local('yum install -y python-devel sqlite-devel libxml2-devel pcre-devel zeromq-devel'
           ' libcap-devel libuuid-devel libev-devel python-greenlet-devel httpd-devel')
 
     # Install Uwsgi
     with temporary_directory(identifier=IDENTIFIER, prefix='init_remote_base') as tmp_directory:
         with lcd(tmp_directory):
-            print cyan('Install uwsgi and mod_uwsgi')
+            print section_title('Install uwsgi and mod_uwsgi')
             # Get source code
             local('wget http://projects.unbit.it/downloads/uwsgi-lts.tar.gz')
             local('tar -zxf uwsgi-lts.tar.gz')
@@ -60,7 +61,7 @@ def setup(settings_path=None, **settings_patches):
     with settings(hide('everything'), warn_only=True):
         has_beanstalk_user = local('egrep ^beanstalk: /etc/passwd').return_code == 0
     if not has_beanstalk_user:
-        print cyan('Create user ') + cyan('"beanstalk"', bold=True)
+        print section_title('Create user "beanstalk"')
         # Create user
         local('useradd beanstalk')
         # Setup user password
@@ -71,7 +72,7 @@ def setup(settings_path=None, **settings_patches):
         local('su -c "git config --global user.email beanstalk@beanstalk-stack.com" - beanstalk')
 
     # Apache command
-    print cyan('Create apache-reload command')
+    print section_title('Create apache-reload command')
     httpd_cmd_path = '/usr/sbin/httpd_reload'
     with open(httpd_cmd_path, 'w') as f:
         f.write('#!/bin/sh\n')
@@ -88,7 +89,7 @@ def setup(settings_path=None, **settings_patches):
     local('/etc/init.d/sshd restart')
 
     # Create homebase
-    print cyan('Deploy target is: ') + cyan('%s' % beanstalk_stack_base, bold=True)
+    print section_title('Deploy target is: %s' % beanstalk_stack_base)
     local('mkdir -p %s' % beanstalk_stack_base)
     local('chmod o+rx %s' % beanstalk_stack_base)
     local('chown beanstalk:beanstalk %s' % beanstalk_stack_base)
